Method: ActiveScraper::ResponseObject::Basic#headers
- Defined in:
- lib/active_scraper/response_object/basic.rb
#headers ⇒ Object (readonly)
I don’t really know what to name this but this is passed between the various classes, including the Fetcher, and is expected to behave the same in those interactions
8 9 10 |
# File 'lib/active_scraper/response_object/basic.rb', line 8 def headers @headers end |